==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/UploadArtifactWith.java <==
package io.github.cdklabs.projen.github;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.441Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.UploadArtifactWith")
@software.amazon.jsii.Jsii.Proxy(UploadArtifactWith.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface UploadArtifactWith extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) A file, directory or wildcard pattern that describes what to upload.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getPath();

    /**
     * (experimental) The level of compression for Zlib to be applied to the artifact archive.
     * <p>
     * The value can range from 0 to 9.
     * For large files that are not easily compressed, a value of 0 is recommended for significantly faster uploads.
     * <p>
     * Default: 6
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Number getCompressionLevel() {
        return null;
    }

    /**
     * (experimental) The desired behavior if no files are found using the provided path.
     * <p>
     * Available Options:
     * warn: Output a warning but do not fail the action
     * error: Fail the action with an error message
     * ignore: Do not output any warnings or errors, the action does not fail
     * <p>
     * Default: "warn"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getIfNoFilesFound() {
        return null;
    }

    /**
     * (experimental) Name of the artifact to upload.
     * <p>
     * Default: "artifact"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getName() {
        return null;
    }

    /**
     * (experimental) Duration after which artifact will expire in days. 0 means using default repository retention.
     * <p>
     * Minimum 1 day.
     * Maximum 90 days unless changed from the repository settings page.
     * <p>
     * Default: - The default repository retention
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Number getRetentionDays() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link UploadArtifactWith}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link UploadArtifactWith}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<UploadArtifactWith> {
        java.lang.String path;
        java.lang.Number compressionLevel;
        java.lang.String ifNoFilesFound;
        java.lang.String name;
        java.lang.Number retentionDays;

        /**
         * Sets the value of {@link UploadArtifactWith#getPath}
         * @param path A file, directory or wildcard pattern that describes what to upload. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder path(java.lang.String path) {
            this.path = path;
            return this;
        }

        /**
         * Sets the value of {@link UploadArtifactWith#getCompressionLevel}
         * @param compressionLevel The level of compression for Zlib to be applied to the artifact archive.
         *                         The value can range from 0 to 9.
         *                         For large files that are not easily compressed, a value of 0 is recommended for significantly faster uploads.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder compressionLevel(java.lang.Number compressionLevel) {
            this.compressionLevel = compressionLevel;
            return this;
        }

        /**
         * Sets the value of {@link UploadArtifactWith#getIfNoFilesFound}
         * @param ifNoFilesFound The desired behavior if no files are found using the provided path.
         *                       Available Options:
         *                       warn: Output a warning but do not fail the action
         *                       error: Fail the action with an error message
         *                       ignore: Do not output any warnings or errors, the action does not fail
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ifNoFilesFound(java.lang.String ifNoFilesFound) {
            this.ifNoFilesFound = ifNoFilesFound;
            return this;
        }

        /**
         * Sets the value of {@link UploadArtifactWith#getName}
         * @param name Name of the artifact to upload.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link UploadArtifactWith#getRetentionDays}
         * @param retentionDays Duration after which artifact will expire in days. 0 means using default repository retention.
         *                      Minimum 1 day.
         *                      Maximum 90 days unless changed from the repository settings page.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder retentionDays(java.lang.Number retentionDays) {
            this.retentionDays = retentionDays;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link UploadArtifactWith}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public UploadArtifactWith build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link UploadArtifactWith}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements UploadArtifactWith {
        private final java.lang.String path;
        private final java.lang.Number compressionLevel;
        private final java.lang.String ifNoFilesFound;
        private final java.lang.String name;
        private final java.lang.Number retentionDays;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.path = software.amazon.jsii.Kernel.get(this, "path", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.compressionLevel = software.amazon.jsii.Kernel.get(this, "compressionLevel", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.ifNoFilesFound = software.amazon.jsii.Kernel.get(this, "ifNoFilesFound", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.retentionDays = software.amazon.jsii.Kernel.get(this, "retentionDays", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.path = java.util.Objects.requireNonNull(builder.path, "path is required");
            this.compressionLevel = builder.compressionLevel;
            this.ifNoFilesFound = builder.ifNoFilesFound;
            this.name = builder.name;
            this.retentionDays = builder.retentionDays;
        }

        @Override
        public final java.lang.String getPath() {
            return this.path;
        }

        @Override
        public final java.lang.Number getCompressionLevel() {
            return this.compressionLevel;
        }

        @Override
        public final java.lang.String getIfNoFilesFound() {
            return this.ifNoFilesFound;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.Number getRetentionDays() {
            return this.retentionDays;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("path", om.valueToTree(this.getPath()));
            if (this.getCompressionLevel() != null) {
                data.set("compressionLevel", om.valueToTree(this.getCompressionLevel()));
            }
            if (this.getIfNoFilesFound() != null) {
                data.set("ifNoFilesFound", om.valueToTree(this.getIfNoFilesFound()));
            }
            if (this.getName() != null) {
                data.set("name", om.valueToTree(this.getName()));
            }
            if (this.getRetentionDays() != null) {
                data.set("retentionDays", om.valueToTree(this.getRetentionDays()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.UploadArtifactWith"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            UploadArtifactWith.Jsii$Proxy that = (UploadArtifactWith.Jsii$Proxy) o;

            if (!path.equals(that.path)) return false;
            if (this.compressionLevel != null ? !this.compressionLevel.equals(that.compressionLevel) : that.compressionLevel != null) return false;
            if (this.ifNoFilesFound != null ? !this.ifNoFilesFound.equals(that.ifNoFilesFound) : that.ifNoFilesFound != null) return false;
            if (this.name != null ? !this.name.equals(that.name) : that.name != null) return false;
            return this.retentionDays != null ? this.retentionDays.equals(that.retentionDays) : that.retentionDays == null;
        }

        @Override
        public final int hashCode() {
            int result = this.path.hashCode();
            result = 31 * result + (this.compressionLevel != null ? this.compressionLevel.hashCode() : 0);
            result = 31 * result + (this.ifNoFilesFound != null ? this.ifNoFilesFound.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            result = 31 * result + (this.retentionDays != null ? this.retentionDays.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.80.4-sources.jar: io/github/cdklabs/projen/github/UploadArtifactWith.java <==
package io.github.cdklabs.projen.github;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-28T17:20:29.248Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.UploadArtifactWith")
@software.amazon.jsii.Jsii.Proxy(UploadArtifactWith.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface UploadArtifactWith extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) A file, directory or wildcard pattern that describes what to upload.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getPath();

    /**
     * (experimental) The level of compression for Zlib to be applied to the artifact archive.
     * <p>
     * The value can range from 0 to 9.
     * For large files that are not easily compressed, a value of 0 is recommended for significantly faster uploads.
     * <p>
     * Default: 6
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Number getCompressionLevel() {
        return null;
    }

    /**
     * (experimental) The desired behavior if no files are found using the provided path.
     * <p>
     * Available Options:
     * warn: Output a warning but do not fail the action
     * error: Fail the action with an error message
     * ignore: Do not output any warnings or errors, the action does not fail
     * <p>
     * Default: "warn"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getIfNoFilesFound() {
        return null;
    }

    /**
     * (experimental) Name of the artifact to upload.
     * <p>
     * Default: "artifact"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getName() {
        return null;
    }

    /**
     * (experimental) Whether action should overwrite an existing artifact with the same name (should one exist).
     * <p>
     * Introduced in v4 and represents a breaking change from the behavior of the v3 action.
     * To maintain backwards compatibility with existing, this should be set the <code>true</code> (the default).
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getOverwrite() {
        return null;
    }

    /**
     * (experimental) Duration after which artifact will expire in days. 0 means using default repository retention.
     * <p>
     * Minimum 1 day.
     * Maximum 90 days unless changed from the repository settings page.
     * <p>
     * Default: - The default repository retention
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Number getRetentionDays() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link UploadArtifactWith}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link UploadArtifactWith}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<UploadArtifactWith> {
        java.lang.String path;
        java.lang.Number compressionLevel;
        java.lang.String ifNoFilesFound;
        java.lang.String name;
        java.lang.Boolean overwrite;
        java.lang.Number retentionDays;

        /**
         * Sets the value of {@link UploadArtifactWith#getPath}
         * @param path A file, directory or wildcard pattern that describes what to upload. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder path(java.lang.String path) {
            this.path = path;
            return this;
        }

        /**
         * Sets the value of {@link UploadArtifactWith#getCompressionLevel}
         * @param compressionLevel The level of compression for Zlib to be applied to the artifact archive.
         *                         The value can range from 0 to 9.
         *                         For large files that are not easily compressed, a value of 0 is recommended for significantly faster uploads.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder compressionLevel(java.lang.Number compressionLevel) {
            this.compressionLevel = compressionLevel;
            return this;
        }

        /**
         * Sets the value of {@link UploadArtifactWith#getIfNoFilesFound}
         * @param ifNoFilesFound The desired behavior if no files are found using the provided path.
         *                       Available Options:
         *                       warn: Output a warning but do not fail the action
         *                       error: Fail the action with an error message
         *                       ignore: Do not output any warnings or errors, the action does not fail
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ifNoFilesFound(java.lang.String ifNoFilesFound) {
            this.ifNoFilesFound = ifNoFilesFound;
            return this;
        }

        /**
         * Sets the value of {@link UploadArtifactWith#getName}
         * @param name Name of the artifact to upload.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link UploadArtifactWith#getOverwrite}
         * @param overwrite Whether action should overwrite an existing artifact with the same name (should one exist).
         *                  Introduced in v4 and represents a breaking change from the behavior of the v3 action.
         *                  To maintain backwards compatibility with existing, this should be set the <code>true</code> (the default).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder overwrite(java.lang.Boolean overwrite) {
            this.overwrite = overwrite;
            return this;
        }

        /**
         * Sets the value of {@link UploadArtifactWith#getRetentionDays}
         * @param retentionDays Duration after which artifact will expire in days. 0 means using default repository retention.
         *                      Minimum 1 day.
         *                      Maximum 90 days unless changed from the repository settings page.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder retentionDays(java.lang.Number retentionDays) {
            this.retentionDays = retentionDays;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link UploadArtifactWith}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public UploadArtifactWith build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link UploadArtifactWith}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements UploadArtifactWith {
        private final java.lang.String path;
        private final java.lang.Number compressionLevel;
        private final java.lang.String ifNoFilesFound;
        private final java.lang.String name;
        private final java.lang.Boolean overwrite;
        private final java.lang.Number retentionDays;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.path = software.amazon.jsii.Kernel.get(this, "path", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.compressionLevel = software.amazon.jsii.Kernel.get(this, "compressionLevel", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.ifNoFilesFound = software.amazon.jsii.Kernel.get(this, "ifNoFilesFound", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.overwrite = software.amazon.jsii.Kernel.get(this, "overwrite", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.retentionDays = software.amazon.jsii.Kernel.get(this, "retentionDays", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.path = java.util.Objects.requireNonNull(builder.path, "path is required");
            this.compressionLevel = builder.compressionLevel;
            this.ifNoFilesFound = builder.ifNoFilesFound;
            this.name = builder.name;
            this.overwrite = builder.overwrite;
            this.retentionDays = builder.retentionDays;
        }

        @Override
        public final java.lang.String getPath() {
            return this.path;
        }

        @Override
        public final java.lang.Number getCompressionLevel() {
            return this.compressionLevel;
        }

        @Override
        public final java.lang.String getIfNoFilesFound() {
            return this.ifNoFilesFound;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.Boolean getOverwrite() {
            return this.overwrite;
        }

        @Override
        public final java.lang.Number getRetentionDays() {
            return this.retentionDays;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("path", om.valueToTree(this.getPath()));
            if (this.getCompressionLevel() != null) {
                data.set("compressionLevel", om.valueToTree(this.getCompressionLevel()));
            }
            if (this.getIfNoFilesFound() != null) {
                data.set("ifNoFilesFound", om.valueToTree(this.getIfNoFilesFound()));
            }
            if (this.getName() != null) {
                data.set("name", om.valueToTree(this.getName()));
            }
            if (this.getOverwrite() != null) {
                data.set("overwrite", om.valueToTree(this.getOverwrite()));
            }
            if (this.getRetentionDays() != null) {
                data.set("retentionDays", om.valueToTree(this.getRetentionDays()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.UploadArtifactWith"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            UploadArtifactWith.Jsii$Proxy that = (UploadArtifactWith.Jsii$Proxy) o;

            if (!path.equals(that.path)) return false;
            if (this.compressionLevel != null ? !this.compressionLevel.equals(that.compressionLevel) : that.compressionLevel != null) return false;
            if (this.ifNoFilesFound != null ? !this.ifNoFilesFound.equals(that.ifNoFilesFound) : that.ifNoFilesFound != null) return false;
            if (this.name != null ? !this.name.equals(that.name) : that.name != null) return false;
            if (this.overwrite != null ? !this.overwrite.equals(that.overwrite) : that.overwrite != null) return false;
            return this.retentionDays != null ? this.retentionDays.equals(that.retentionDays) : that.retentionDays == null;
        }

        @Override
        public final int hashCode() {
            int result = this.path.hashCode();
            result = 31 * result + (this.compressionLevel != null ? this.compressionLevel.hashCode() : 0);
            result = 31 * result + (this.ifNoFilesFound != null ? this.ifNoFilesFound.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            result = 31 * result + (this.overwrite != null ? this.overwrite.hashCode() : 0);
            result = 31 * result + (this.retentionDays != null ? this.retentionDays.hashCode() : 0);
            return result;
        }
    }
}
